@@ -452,7 +452,7 @@ io_watch_stdout (GIOChannel *source, GIOCondition condition, PasswordDialog *pdi
 		case PASSWD_STATE_AUTH:
 			/* Passwd is asking for our current password */
 
-			if (is_string_complete (str->str, "assword: ", "failure", "wrong", NULL)) {
+			if (is_string_complete (str->str, "assword: ", "failure", "wrong", "error", NULL)) {
 				/* Which response did we get? */
 				passdlg_set_busy (pdialog, FALSE);
 
@@ -500,18 +500,20 @@ io_watch_stdout (GIOChannel *source, GIOCondition condition, PasswordDialog *pdi
 			/* Passwd is asking for our retyped new password */
 
 			if (is_string_complete (str->str, "successfully",
-											  "short",
-											  "longer",
-											  "palindrome",
-											  "simple",
-											  "similar",
-											  "wrapped",
-											  "recovered",
-											  "unchanged",
-											  "match",
-											  "1 numeric or special",
-											  "failure",
-											  NULL)) {
+							  "short",
+							  "longer",
+							  "palindrome",
+							  "dictionary",
+							  "simple",
+							  "similar",
+							  "case",
+							  "wrapped",
+							  "recovered",
+							  "unchanged",
+							  "match",
+							  "1 numeric or special",
+							  "failure",
+							  NULL)) {
 
 				/* What response did we get? */
 				passdlg_set_busy (pdialog, FALSE);
@@ -535,9 +537,11 @@ io_watch_stdout (GIOChannel *source, GIOCondition condition, PasswordDialog *pdi
 						   g_strrstr (str->str, "longer") != NULL) {
 						msg = g_strdup (_("The password is too short."));
 					} else if (g_strrstr (str->str, "palindrome") != NULL ||
-						   g_strrstr (str->str, "simple") != NULL) {
+						   g_strrstr (str->str, "simple") != NULL ||
+						   g_strrstr (str->str, "dictionary") != NULL) {
 						msg = g_strdup (_("The password is too simple."));
 					} else if (g_strrstr (str->str, "similar") != NULL ||
+					           g_strrstr (str->str, "case") != NULL ||
 						   g_strrstr (str->str, "wrapped") != NULL) {
 						msg = g_strdup (_("The old and new passwords are too similar."));
 					} else if (g_strrstr (str->str, "1 numeric or special") != NULL) {
