@@ -29,6 +29,7 @@
 #include <gdk/gdkx.h>
 #include <X11/Xft/Xft.h>
 #endif /* HAVE_XFT2 */
+#include <glib/gi18n.h>
 
 #include "capplet-util.h"
 #include "gconf-property-editor.h"
@@ -104,9 +105,8 @@ sample_expose (GtkWidget      *darea,
 		      0, 0,
 		      darea->allocation.width - 1, darea->allocation.height - 1);
 
-  gdk_pixbuf_render_to_drawable (pixbuf, darea->window, NULL,
-				 0, 0, x, y, width, height,
-				 GDK_RGB_DITHER_NORMAL, 0, 0);
+  gdk_draw_pixbuf (darea->window, NULL, pixbuf, 0, 0, x, y, width, height,
+                   GDK_RGB_DITHER_NORMAL, 0, 0);
 }
 
 typedef enum {
@@ -390,20 +390,20 @@ static void
 font_radio_toggled (GtkToggleButton *toggle_button,
 		    FontPair        *pair)
 {
-  GConfClient *client = gconf_client_get_default ();
-
   if (!in_change) {
+    GConfClient *client = gconf_client_get_default ();
+
     gconf_client_set_string (client, FONT_ANTIALIASING_KEY,
 			     gconf_enum_to_string (antialias_enums, pair->antialiasing),
 			     NULL);
     gconf_client_set_string (client, FONT_HINTING_KEY,
 			     gconf_enum_to_string (hint_enums, pair->hinting),
 			     NULL);
-  }
 
-  /* Restore back to the previous state until we get notification */
-  font_render_load (client);
-  g_object_unref (client);
+    /* Restore back to the previous state until we get notification */
+    font_render_load (client);
+    g_object_unref (client);
+  }
 }
 
 static void
@@ -429,7 +429,7 @@ setup_font_pair (GtkWidget    *radio,
 static void
 metacity_titlebar_load_sensitivity (AppearanceData *data)
 {
-  gtk_widget_set_sensitive (glade_xml_get_widget (data->xml, "window_title_font"),
+  gtk_widget_set_sensitive (appearance_capplet_get_widget (data, "window_title_font"),
 			    !gconf_client_get_bool (data->client,
 						    WINDOW_TITLE_USES_SYSTEM_KEY,
 						    NULL));
@@ -524,10 +524,11 @@ application_font_to_gconf (GConfPropertyEditor *peditor,
 					     GTK_DIALOG_MODAL,
 					     GTK_MESSAGE_WARNING,
 					     GTK_BUTTONS_NONE,
+					     "%s",
 					     warning_label);
 
     gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (warning_dialog),
-					      warning_label2);
+					      "%s", warning_label2);
 
     gtk_dialog_add_button (GTK_DIALOG (warning_dialog),
 			   _("Use previous font"), GTK_RESPONSE_CLOSE);
@@ -791,11 +792,13 @@ dpi_value_changed (GtkSpinButton *spinner,
    * If the user changes the value faster than responses are
    * received from GConf, this may cause mildly strange effects.
    */
-  gdouble new_dpi = gtk_spin_button_get_value (spinner);
+  if (!in_change) {
+    gdouble new_dpi = gtk_spin_button_get_value (spinner);
 
-  gconf_client_set_float (client, FONT_DPI_KEY, new_dpi, NULL);
+    gconf_client_set_float (client, FONT_DPI_KEY, new_dpi, NULL);
 
-  dpi_load (client, spinner);
+    dpi_load (client, spinner);
+  }
 }
 
 static void
@@ -803,11 +806,7 @@ cb_details_response (GtkDialog *dialog, gint response_id)
 {
   if (response_id == GTK_RESPONSE_HELP) {
     capplet_help (GTK_WINDOW (dialog),
-		  "user-guide.xml",
 		  "goscustdesk-38");
-  } else if (response_id == 1) {
-    /* "Go to font folder" was clicked */
-    g_spawn_command_line_async ("nautilus --no-desktop fonts:///", NULL);
   } else
     gtk_widget_hide (GTK_WIDGET (dialog));
 }
@@ -817,29 +816,22 @@ cb_show_details (GtkWidget *button,
 		 AppearanceData *data)
 {
   if (!data->font_details) {
-    GnomeVFSURI *uri;
     GtkAdjustment *adjustment;
     GtkWidget *widget;
     EnumGroup *group;
 
-    data->font_details = glade_xml_get_widget (data->xml, "render_details");
-    uri = gnome_vfs_uri_new ("fonts:///");
-    widget = glade_xml_get_widget (data->xml, "go_to_font_button");
-    if (uri == NULL) {
-      gtk_widget_hide (widget);
-    } else {
-      gnome_vfs_uri_unref (uri);
-      gtk_widget_show (widget);
-    }
+    data->font_details = appearance_capplet_get_widget (data, "render_details");
 
     gtk_window_set_transient_for (GTK_WINDOW (data->font_details),
-				  GTK_WINDOW (glade_xml_get_widget (data->xml, "appearance_window")));
+                                  GTK_WINDOW (appearance_capplet_get_widget (data, "appearance_window")));
 
-    widget = glade_xml_get_widget (data->xml, "dpi_spinner");
+    widget = appearance_capplet_get_widget (data, "dpi_spinner");
 
     /* pick a sensible maximum dpi */
     adjustment = gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON (widget));
     adjustment->upper = DPI_HIGH_REASONABLE_VALUE;
+    adjustment->lower = DPI_LOW_REASONABLE_VALUE;
+    adjustment->step_increment = 1;
 
     dpi_load (data->client, GTK_SPIN_BUTTON (widget));
     g_signal_connect (widget, "value_changed",
@@ -848,48 +840,46 @@ cb_show_details (GtkWidget *button,
     gconf_client_notify_add (data->client, FONT_DPI_KEY,
 			     dpi_changed, widget, NULL, NULL);
 
-    setup_font_sample (glade_xml_get_widget (data->xml, "antialias_none_sample"),      ANTIALIAS_NONE,      HINT_FULL);
-    setup_font_sample (glade_xml_get_widget (data->xml, "antialias_grayscale_sample"), ANTIALIAS_GRAYSCALE, HINT_FULL);
-    setup_font_sample (glade_xml_get_widget (data->xml, "antialias_subpixel_sample"),  ANTIALIAS_RGBA,      HINT_FULL);
+    setup_font_sample (appearance_capplet_get_widget (data, "antialias_none_sample"),      ANTIALIAS_NONE,      HINT_FULL);
+    setup_font_sample (appearance_capplet_get_widget (data, "antialias_grayscale_sample"), ANTIALIAS_GRAYSCALE, HINT_FULL);
+    setup_font_sample (appearance_capplet_get_widget (data, "antialias_subpixel_sample"),  ANTIALIAS_RGBA,      HINT_FULL);
 
     group = enum_group_create (
     	FONT_ANTIALIASING_KEY, antialias_enums, ANTIALIAS_GRAYSCALE,
-	glade_xml_get_widget (data->xml, "antialias_none_radio"),      ANTIALIAS_NONE,
-	glade_xml_get_widget (data->xml, "antialias_grayscale_radio"), ANTIALIAS_GRAYSCALE,
-	glade_xml_get_widget (data->xml, "antialias_subpixel_radio"),  ANTIALIAS_RGBA,
+	appearance_capplet_get_widget (data, "antialias_none_radio"),      ANTIALIAS_NONE,
+	appearance_capplet_get_widget (data, "antialias_grayscale_radio"), ANTIALIAS_GRAYSCALE,
+	appearance_capplet_get_widget (data, "antialias_subpixel_radio"),  ANTIALIAS_RGBA,
 	NULL);
     data->font_groups = g_slist_prepend (data->font_groups, group);
 
-    setup_font_sample (glade_xml_get_widget (data->xml, "hint_none_sample"),   ANTIALIAS_GRAYSCALE, HINT_NONE);
-    setup_font_sample (glade_xml_get_widget (data->xml, "hint_slight_sample"), ANTIALIAS_GRAYSCALE, HINT_SLIGHT);
-    setup_font_sample (glade_xml_get_widget (data->xml, "hint_medium_sample"), ANTIALIAS_GRAYSCALE, HINT_MEDIUM);
-    setup_font_sample (glade_xml_get_widget (data->xml, "hint_full_sample"),   ANTIALIAS_GRAYSCALE, HINT_FULL);
+    setup_font_sample (appearance_capplet_get_widget (data, "hint_none_sample"),   ANTIALIAS_GRAYSCALE, HINT_NONE);
+    setup_font_sample (appearance_capplet_get_widget (data, "hint_slight_sample"), ANTIALIAS_GRAYSCALE, HINT_SLIGHT);
+    setup_font_sample (appearance_capplet_get_widget (data, "hint_medium_sample"), ANTIALIAS_GRAYSCALE, HINT_MEDIUM);
+    setup_font_sample (appearance_capplet_get_widget (data, "hint_full_sample"),   ANTIALIAS_GRAYSCALE, HINT_FULL);
 
-    group = enum_group_create (
-    	FONT_HINTING_KEY, hint_enums, HINT_FULL,
-	glade_xml_get_widget (data->xml, "hint_none_radio"),   HINT_NONE,
-	glade_xml_get_widget (data->xml, "hint_slight_radio"), HINT_SLIGHT,
-	glade_xml_get_widget (data->xml, "hint_medium_radio"), HINT_MEDIUM,
-	glade_xml_get_widget (data->xml, "hint_full_radio"),   HINT_FULL,
-	NULL);
+    group = enum_group_create (FONT_HINTING_KEY, hint_enums, HINT_FULL,
+                               appearance_capplet_get_widget (data, "hint_none_radio"),   HINT_NONE,
+                               appearance_capplet_get_widget (data, "hint_slight_radio"), HINT_SLIGHT,
+                               appearance_capplet_get_widget (data, "hint_medium_radio"), HINT_MEDIUM,
+                               appearance_capplet_get_widget (data, "hint_full_radio"),   HINT_FULL,
+                               NULL);
     data->font_groups = g_slist_prepend (data->font_groups, group);
 
-    gtk_image_set_from_file (GTK_IMAGE (glade_xml_get_widget (data->xml, "subpixel_rgb_image")),
-			     GNOMECC_PIXMAP_DIR "/subpixel-rgb.png");
-    gtk_image_set_from_file (GTK_IMAGE (glade_xml_get_widget (data->xml, "subpixel_bgr_image")),
-			     GNOMECC_PIXMAP_DIR "/subpixel-bgr.png");
-    gtk_image_set_from_file (GTK_IMAGE (glade_xml_get_widget (data->xml, "subpixel_vrgb_image")),
-			     GNOMECC_PIXMAP_DIR "/subpixel-vrgb.png");
-    gtk_image_set_from_file (GTK_IMAGE (glade_xml_get_widget (data->xml, "subpixel_vbgr_image")),
-			     GNOMECC_PIXMAP_DIR "/subpixel-vbgr.png");
+    gtk_image_set_from_file (GTK_IMAGE (appearance_capplet_get_widget (data, "subpixel_rgb_image")),
+                             GNOMECC_PIXMAP_DIR "/subpixel-rgb.png");
+    gtk_image_set_from_file (GTK_IMAGE (appearance_capplet_get_widget (data, "subpixel_bgr_image")),
+                             GNOMECC_PIXMAP_DIR "/subpixel-bgr.png");
+    gtk_image_set_from_file (GTK_IMAGE (appearance_capplet_get_widget (data, "subpixel_vrgb_image")),
+                             GNOMECC_PIXMAP_DIR "/subpixel-vrgb.png");
+    gtk_image_set_from_file (GTK_IMAGE (appearance_capplet_get_widget (data, "subpixel_vbgr_image")),
+                             GNOMECC_PIXMAP_DIR "/subpixel-vbgr.png");
 
-    group = enum_group_create (
-    	FONT_RGBA_ORDER_KEY, rgba_order_enums, RGBA_RGB,
-	glade_xml_get_widget (data->xml, "subpixel_rgb_radio"),  RGBA_RGB,
-	glade_xml_get_widget (data->xml, "subpixel_bgr_radio"),  RGBA_BGR,
-	glade_xml_get_widget (data->xml, "subpixel_vrgb_radio"), RGBA_VRGB,
-	glade_xml_get_widget (data->xml, "subpixel_vbgr_radio"), RGBA_VBGR,
-	NULL);
+    group = enum_group_create (FONT_RGBA_ORDER_KEY, rgba_order_enums, RGBA_RGB,
+                               appearance_capplet_get_widget (data, "subpixel_rgb_radio"),  RGBA_RGB,
+                               appearance_capplet_get_widget (data, "subpixel_bgr_radio"),  RGBA_BGR,
+                               appearance_capplet_get_widget (data, "subpixel_vrgb_radio"), RGBA_VRGB,
+                               appearance_capplet_get_widget (data, "subpixel_vbgr_radio"), RGBA_VBGR,
+                               NULL);
     data->font_groups = g_slist_prepend (data->font_groups, group);
 
     g_signal_connect (G_OBJECT (data->font_details),
@@ -924,7 +914,7 @@ font_init (AppearanceData *data)
 			GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 #endif  /* HAVE_XFT2 */
 
-  widget = glade_xml_get_widget (data->xml, "application_font");
+  widget = appearance_capplet_get_widget (data, "application_font");
   peditor = gconf_peditor_new_font (NULL, GTK_FONT_KEY,
 				    widget,
 				    "conv-from-widget-cb", application_font_to_gconf,
@@ -935,20 +925,20 @@ font_init (AppearanceData *data)
   application_font_changed (widget);
 
   peditor = gconf_peditor_new_font (NULL, DOCUMENT_FONT_KEY,
-				    glade_xml_get_widget (data->xml, "document_font"),
-				    NULL);
+                                    appearance_capplet_get_widget (data, "document_font"),
+                                    NULL);
 
   peditor = gconf_peditor_new_font (NULL, DESKTOP_FONT_KEY,
-				    glade_xml_get_widget (data->xml, "desktop_font"),
-				    NULL);
+                                    appearance_capplet_get_widget (data, "desktop_font"),
+                                    NULL);
 
   peditor = gconf_peditor_new_font (NULL, WINDOW_TITLE_FONT_KEY,
-				    glade_xml_get_widget (data->xml, "window_title_font"),
-				    NULL);
+                                    appearance_capplet_get_widget (data, "window_title_font"),
+                                    NULL);
 
   peditor = gconf_peditor_new_font (NULL, MONOSPACE_FONT_KEY,
-				    glade_xml_get_widget (data->xml, "monospace_font"),
-				    NULL);
+                                    appearance_capplet_get_widget (data, "monospace_font"),
+                                    NULL);
 
   gconf_client_notify_add (data->client, WINDOW_TITLE_USES_SYSTEM_KEY,
 			   metacity_changed,
@@ -957,18 +947,18 @@ font_init (AppearanceData *data)
   metacity_titlebar_load_sensitivity (data);
 
 #ifdef HAVE_XFT2
-  setup_font_pair (glade_xml_get_widget (data->xml, "monochrome_radio"),
-		   glade_xml_get_widget (data->xml, "monochrome_sample"),
-		   ANTIALIAS_NONE, HINT_FULL);
-  setup_font_pair (glade_xml_get_widget (data->xml, "best_shapes_radio"),
-		   glade_xml_get_widget (data->xml, "best_shapes_sample"),
-		   ANTIALIAS_GRAYSCALE, HINT_MEDIUM);
-  setup_font_pair (glade_xml_get_widget (data->xml, "best_contrast_radio"),
-		   glade_xml_get_widget (data->xml, "best_contrast_sample"),
-		   ANTIALIAS_GRAYSCALE, HINT_FULL);
-  setup_font_pair (glade_xml_get_widget (data->xml, "subpixel_radio"),
-		   glade_xml_get_widget (data->xml, "subpixel_sample"),
-		   ANTIALIAS_RGBA, HINT_FULL);
+  setup_font_pair (appearance_capplet_get_widget (data, "monochrome_radio"),
+                   appearance_capplet_get_widget (data, "monochrome_sample"),
+                   ANTIALIAS_NONE, HINT_FULL);
+  setup_font_pair (appearance_capplet_get_widget (data, "best_shapes_radio"),
+                   appearance_capplet_get_widget (data, "best_shapes_sample"),
+                   ANTIALIAS_GRAYSCALE, HINT_MEDIUM);
+  setup_font_pair (appearance_capplet_get_widget (data, "best_contrast_radio"),
+                   appearance_capplet_get_widget (data, "best_contrast_sample"),
+                   ANTIALIAS_GRAYSCALE, HINT_FULL);
+  setup_font_pair (appearance_capplet_get_widget (data, "subpixel_radio"),
+                   appearance_capplet_get_widget (data, "subpixel_sample"),
+                   ANTIALIAS_RGBA, HINT_FULL);
 
   font_render_load (data->client);
 
@@ -976,10 +966,10 @@ font_init (AppearanceData *data)
 			   font_render_changed,
 			   data->client, NULL, NULL);
 
-  g_signal_connect (glade_xml_get_widget (data->xml, "details_button"),
-		    "clicked", G_CALLBACK (cb_show_details), data);
+  g_signal_connect (appearance_capplet_get_widget (data, "details_button"),
+                    "clicked", G_CALLBACK (cb_show_details), data);
 #else /* !HAVE_XFT2 */
-  gtk_widget_hide (glade_xml_get_widget (data->xml, "font_render_frame"));
+  gtk_widget_hide (appearance_capplet_get_widget (data, "font_render_frame"));
 #endif /* HAVE_XFT2 */
 }
 
