@@ -29,7 +29,6 @@
 #endif
 
 #include <gconf/gconf-client.h>
-#include <glade/glade.h>
 
 #include "capplet-util.h"
 #include "gconf-property-editor.h"
@@ -44,17 +43,17 @@ enum {
 	RESPONSE_CLOSE
 };
 
-static GladeXML *
+static GtkBuilder *
 create_dialog (void)
 {
-	GladeXML *dialog;
+	GtkBuilder *dialog;
 	GtkSizeGroup *size_group;
 	GtkWidget *image;
 
-	dialog =
-	    glade_xml_new (GNOMECC_GLADE_DIR
-			   "/gnome-keyboard-properties.glade",
-			   "keyboard_dialog", NULL);
+	dialog = gtk_builder_new ();
+    gtk_builder_add_from_file (dialog, GNOMECC_UI_DIR
+                               "/gnome-keyboard-properties-dialog.ui",
+                               NULL);
 
 	size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	gtk_size_group_add_widget (size_group, WID ("repeat_slow_label"));
@@ -80,9 +79,6 @@ create_dialog (void)
 	image = gtk_image_new_from_stock (GTK_STOCK_REFRESH, GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_image (GTK_BUTTON (WID ("xkb_reset_to_defaults")), image);
 
-	image = gtk_image_new_from_icon_name ("gnome-sound-properties", GTK_ICON_SIZE_BUTTON);
-	gtk_button_set_image (GTK_BUTTON (WID ("notifications_button")), image);
-
 	return dialog;
 }
 
@@ -123,7 +119,7 @@ dialog_response (GtkWidget * widget,
 }
 
 static void
-setup_dialog (GladeXML * dialog, GConfChangeSet * changeset)
+setup_dialog (GtkBuilder * dialog, GConfChangeSet * changeset)
 {
 	GObject *peditor;
 	gchar *monitor;
@@ -196,7 +192,7 @@ main (int argc, char **argv)
 {
 	GConfClient *client;
 	GConfChangeSet *changeset;
-	GladeXML *dialog;
+	GtkBuilder *dialog;
 	GOptionContext *context;
 
 	static gboolean apply_only = FALSE;
@@ -226,7 +222,7 @@ main (int argc, char **argv)
 		{NULL}
 	};
 
-	
+
 	context = g_option_context_new (_("- GNOME Keyboard Preferences"));
 	g_option_context_add_main_entries (context, cap_options,
 					   GETTEXT_PACKAGE);
@@ -257,9 +253,9 @@ main (int argc, char **argv)
 					       (WID
 						("keyboard_notebook")),
 					       2);
-		
+
 	}
-	
+
 	capplet_set_icon (WID ("keyboard_dialog"),
 			  "preferences-desktop-keyboard");
 	gtk_widget_show (WID ("keyboard_dialog"));
